Datasets
========

Built-in dataset loaders for examples and testing. Each function returns a
pandas ``Series`` with an appropriate index. See :doc:`/user-guide/datasets`
for a summary table.

.. autofunction:: dynaris.datasets.data.load_nile

.. autofunction:: dynaris.datasets.data.load_airline

.. autofunction:: dynaris.datasets.data.load_lynx

.. autofunction:: dynaris.datasets.data.load_sunspots

.. autofunction:: dynaris.datasets.data.load_temperature

.. autofunction:: dynaris.datasets.data.load_gdp
